@@ -16,6 +16,7 @@
 import collections
 import copy
 import datetime as dt
+import six
 import uuid
 
 from rally.common import db
@@ -446,7 +447,7 @@ class Task(object):
                 actions_list.extend(action["children"])
 
         for e in result["error"]:
-            if not isinstance(e, str):
+            if not isinstance(e, (six.string_types, six.text_type)):
                 LOG.warning("error value has wrong type '%s', should be 'str'"
                             % type(e))
                 return False
