@@ -31,21 +31,22 @@ def load():
 
         opts.register()
 
-        discover.import_modules_from_package("rally.deployment.engines")
-        discover.import_modules_from_package("rally.deployment.serverprovider")
         discover.import_modules_from_package("rally.plugins.common")
         try:
             import rally_openstack  # noqa
         except ImportError:
             discover.LOG.warning(
                 "OpenStack plugins moved to the separate package "
-                "(see https://pypi.python.org/pypi/rally-openstack). In-tree "
+                "(see https://pypi.org/project/rally-openstack). In-tree "
                 "OpenStack plugins will be removed from the Rally main package"
                 " soon.")
             discover.import_modules_from_package("rally.plugins.openstack")
             discover.import_modules_from_package("rally.plugins.workload")
 
-        discover.import_modules_by_entry_point()
+        packages = discover.import_modules_by_entry_point()
+        for package in packages:
+            if "options" in package:
+                opts.register_options_from_path(package["options"])
 
         discover.load_plugins("/opt/rally/plugins/")
         discover.load_plugins(os.path.expanduser("~/.rally/plugins/"))
