@@ -16,22 +16,19 @@
 import requests
 from six.moves.urllib import parse
 
-from rally.common.i18n import _
-from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import validation
 from rally import consts
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
-from rally.plugins.openstack.cleanup import resources as res_cleanup
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.scenarios.sahara import utils
 from rally.plugins.openstack.scenarios.swift import utils as swift_utils
 from rally.task import context
 
 
-LOG = logging.getLogger(__name__)
-
-
-@context.configure(name="sahara_input_data_sources", order=443)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="sahara_input_data_sources", platform="openstack",
+                   order=443)
 class SaharaInputDataSources(context.Context):
     """Context class for setting up Input Data Sources for an EDP job."""
 
@@ -66,8 +63,6 @@ class SaharaInputDataSources(context.Context):
         "required": ["input_type", "input_url"]
     }
 
-    @logging.log_task_wrapper(LOG.info,
-                              _("Enter context: `Sahara Input Data Sources`"))
     def setup(self):
         utils.init_sahara_context(self)
         self.context["sahara"]["swift_objects"] = []
@@ -100,6 +95,7 @@ class SaharaInputDataSources(context.Context):
                            swift_files, username, password):
         swift_scenario = swift_utils.SwiftScenario(clients=clients,
                                                    context=self.context)
+        # TODO(astudenov): use self.generate_random_name()
         container_name = "rally_" + parse.urlparse(input_url).netloc.rstrip(
             ".sahara")
         self.context["sahara"]["container_name"] = (
@@ -118,17 +114,14 @@ class SaharaInputDataSources(context.Context):
             self.context["tenants"][tenant_id]["sahara"]["input"] = (
                 input_ds_swift.id)
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `Sahara Input Data"
-                                          "Sources`"))
     def cleanup(self):
-        resources = ["data_sources"]
-        for swift_object in self.context["sahara"]["swift_objects"]:
-            res_cleanup.SwiftObject(resource=swift_object[1])
-        res_cleanup.SwiftContainer(
-            resource=self.context["sahara"]["container_name"])
-
         resource_manager.cleanup(
-            names=["sahara.%s" % res for res in resources],
+            names=["swift.object", "swift.container"],
             users=self.context.get("users", []),
-            superclass=utils.SaharaScenario,
-            task_id=self.context["task"]["uuid"])
+            superclass=swift_utils.SwiftScenario,
+            task_id=self.get_owner_id())
+        resource_manager.cleanup(
+            names=["sahara.data_sources"],
+            users=self.context.get("users", []),
+            superclass=self.__class__,
+            task_id=self.get_owner_id())
