@@ -13,21 +13,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from rally.common.i18n import _
-from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import validation
 from rally import consts
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.scenarios.sahara import utils
 from rally.plugins.openstack.scenarios.swift import utils as swift_utils
 from rally.task import context
 
 
-LOG = logging.getLogger(__name__)
-
-
-@context.configure(name="sahara_output_data_sources", order=444)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="sahara_output_data_sources", platform="openstack",
+                   order=444)
 class SaharaOutputDataSources(context.Context):
     """Context class for setting up Output Data Sources for an EDP job."""
 
@@ -46,8 +44,6 @@ class SaharaOutputDataSources(context.Context):
         "required": ["output_type", "output_url_prefix"]
     }
 
-    @logging.log_task_wrapper(LOG.info,
-                              _("Enter context: `Sahara Output Data Sources`"))
     def setup(self):
         utils.init_sahara_context(self)
         for user, tenant_id in rutils.iterate_per_tenants(
@@ -96,12 +92,14 @@ class SaharaOutputDataSources(context.Context):
             output_ds_swift.id
         )
 
-    @logging.log_task_wrapper(LOG.info,
-                              _("Exit context: `Sahara Output Data Sources`"))
     def cleanup(self):
-        resources = ["data_sources"]
         resource_manager.cleanup(
-            names=["sahara.%s" % res for res in resources],
+            names=["swift.object", "swift.container"],
             users=self.context.get("users", []),
-            superclass=utils.SaharaScenario,
-            task_id=self.context["task"]["uuid"])
+            superclass=self.__class__,
+            task_id=self.get_owner_id())
+        resource_manager.cleanup(
+            names=["sahara.data_sources"],
+            users=self.context.get("users", []),
+            superclass=self.__class__,
+            task_id=self.get_owner_id())
