@@ -22,10 +22,10 @@ from rally.task import validation
 """Scenarios for servers using EC2."""
 
 
-@validation.required_services(consts.Service.EC2)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ec2"]},
-                    name="EC2Servers.list_servers")
+@validation.add("required_services", services=[consts.Service.EC2])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ec2"]},
+                    name="EC2Servers.list_servers", platform="openstack")
 class ListServers(utils.EC2Scenario):
 
     def run(self):
@@ -39,11 +39,12 @@ class ListServers(utils.EC2Scenario):
 
 @types.convert(image={"type": "ec2_image"},
                flavor={"type": "ec2_flavor"})
-@validation.image_valid_on_flavor("flavor", "image")
-@validation.required_services(consts.Service.EC2)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ec2"]},
-                    name="EC2Servers.boot_server")
+@validation.add("image_valid_on_flavor", flavor_param="flavor",
+                image_param="image")
+@validation.add("required_services", services=[consts.Service.EC2])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ec2"]},
+                    name="EC2Servers.boot_server", platform="openstack")
 class BootServer(utils.EC2Scenario):
 
     def run(self, image, flavor, **kwargs):
