@@ -13,10 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-"""
-Benchmark scenarios for Keystone.
-"""
-
 from rally.common import logging
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.services.identity import identity
@@ -38,9 +34,10 @@ class KeystoneBasic(scenario.OpenStackScenario):
                 atomic_inst=self.atomic_actions())
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_user")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_user",
+                    platform="openstack")
 class CreateUser(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -55,9 +52,10 @@ class CreateUser(KeystoneBasic):
         self.admin_keystone.create_user(**kwargs)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_delete_user")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_delete_user",
+                    platform="openstack")
 class CreateDeleteUser(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -73,9 +71,10 @@ class CreateDeleteUser(KeystoneBasic):
         self.admin_keystone.delete_user(user.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_user_set_enabled_and_delete")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_user_set_enabled_and_delete",
+                    platform="openstack")
 class CreateUserSetEnabledAndDelete(KeystoneBasic):
 
     def run(self, enabled=True, **kwargs):
@@ -91,9 +90,10 @@ class CreateUserSetEnabledAndDelete(KeystoneBasic):
         self.admin_keystone.delete_user(user.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_tenant")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_tenant",
+                    platform="openstack")
 class CreateTenant(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -107,9 +107,10 @@ class CreateTenant(KeystoneBasic):
         self.admin_keystone.create_project(**kwargs)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.authenticate_user_and_validate_token")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.authenticate_user_and_validate_token",
+                    platform="openstack")
 class AuthenticateUserAndValidateToken(KeystoneBasic):
 
     def run(self):
@@ -118,10 +119,11 @@ class AuthenticateUserAndValidateToken(KeystoneBasic):
         self.admin_keystone.validate_token(token)
 
 
-@validation.number("users_per_tenant", minval=1)
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_tenant_with_users")
+@validation.add("number", param_name="users_per_tenant", minval=1)
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_tenant_with_users",
+                    platform="openstack")
 class CreateTenantWithUsers(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -139,9 +141,10 @@ class CreateTenantWithUsers(KeystoneBasic):
                                          number_of_users=users_per_tenant)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_list_users")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_users",
+                    platform="openstack")
 class CreateAndListUsers(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -159,9 +162,10 @@ class CreateAndListUsers(KeystoneBasic):
         self.admin_keystone.list_users()
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_list_tenants")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_tenants",
+                    platform="openstack")
 class CreateAndListTenants(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -176,9 +180,11 @@ class CreateAndListTenants(KeystoneBasic):
         self.admin_keystone.list_projects()
 
 
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.add_and_remove_user_role")
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.add_and_remove_user_role",
+                    platform="openstack")
 class AddAndRemoveUserRole(KeystoneBasic):
 
     def run(self):
@@ -192,9 +198,10 @@ class AddAndRemoveUserRole(KeystoneBasic):
                                         project_id=tenant_id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_delete_role")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_role",
+                    platform="openstack")
 class CreateAndDeleteRole(KeystoneBasic):
 
     def run(self):
@@ -203,9 +210,11 @@ class CreateAndDeleteRole(KeystoneBasic):
         self.admin_keystone.delete_role(role.id)
 
 
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_add_and_list_user_roles")
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_add_and_list_user_roles",
+                    platform="openstack")
 class CreateAddAndListUserRoles(KeystoneBasic):
 
     def run(self):
@@ -218,9 +227,10 @@ class CreateAddAndListUserRoles(KeystoneBasic):
         self.admin_keystone.list_roles(user_id=user_id, project_id=tenant_id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.get_entities")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.get_entities",
+                    platform="openstack")
 class GetEntities(KeystoneBasic):
 
     def run(self, service_name="keystone"):
@@ -250,9 +260,10 @@ class GetEntities(KeystoneBasic):
         self.admin_keystone.get_service(service.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_delete_service")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_service",
+                    platform="openstack")
 class CreateAndDeleteService(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -269,9 +280,10 @@ class CreateAndDeleteService(KeystoneBasic):
         self.admin_keystone.delete_service(service.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_update_and_delete_tenant")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_update_and_delete_tenant",
+                    platform="openstack")
 class CreateUpdateAndDeleteTenant(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -290,9 +302,10 @@ class CreateUpdateAndDeleteTenant(KeystoneBasic):
         self.admin_keystone.delete_project(project.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_user_update_password")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_user_update_password",
+                    platform="openstack")
 class CreateUserUpdatePassword(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -306,9 +319,10 @@ class CreateUserUpdatePassword(KeystoneBasic):
         self.admin_keystone.update_user(user.id, password=password)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_list_services")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_services",
+                    platform="openstack")
 class CreateAndListServices(KeystoneBasic):
 
     @logging.log_deprecated_args(
@@ -325,9 +339,10 @@ class CreateAndListServices(KeystoneBasic):
         self.admin_keystone.list_services()
 
 
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_list_ec2credentials")
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_ec2credentials",
+                    platform="openstack")
 class CreateAndListEc2Credentials(KeystoneBasic):
 
     def run(self):
@@ -338,9 +353,10 @@ class CreateAndListEc2Credentials(KeystoneBasic):
         self.keystone.list_ec2credentials(self.context["user"]["id"])
 
 
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_delete_ec2credential")
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_delete_ec2credential",
+                    platform="openstack")
 class CreateAndDeleteEc2Credential(KeystoneBasic):
 
     def run(self):
@@ -352,9 +368,10 @@ class CreateAndDeleteEc2Credential(KeystoneBasic):
             self.context["user"]["id"], access=creds.access)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_get_role")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_get_role",
+                    platform="openstack")
 class CreateAndGetRole(KeystoneBasic):
 
     def run(self, **kwargs):
@@ -366,9 +383,10 @@ class CreateAndGetRole(KeystoneBasic):
         self.admin_keystone.get_role(role.id)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_list_roles")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_list_roles",
+                    platform="openstack")
 class CreateAddListRoles(KeystoneBasic):
 
     def run(self, create_role_kwargs=None, list_role_kwargs=None):
@@ -390,9 +408,10 @@ class CreateAddListRoles(KeystoneBasic):
         self.assertIn(role, all_roles, err_msg=msg)
 
 
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["keystone"]},
-                    name="KeystoneBasic.create_and_update_user")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["keystone"]},
+                    name="KeystoneBasic.create_and_update_user",
+                    platform="openstack")
 class CreateAndUpdateUser(KeystoneBasic):
 
     def run(self, create_user_kwargs=None, update_user_kwargs=None):
